//
//  OrderModel.m
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "OrderModel.h"

#import "NSDate+Formatting.h"



@implementation OrderModel

- (instancetype)initWithDictionary:(NSDictionary *)dictionary {
    self = [super initWithDictionary:dictionary];
    if (self) {
        self.phone = dictionary[@"phone"];
        self.state = (OrderState)[dictionary[@"state"] integerValue];
        self.amount = [dictionary[@"amount"] floatValue];
        self.address = dictionary[@"address"];
        
        NSString *dateString = dictionary[@"date"];
        if ([dateString isKindOfClass:[NSString class]]) {
            self.date = [NSDate dateFromString:dateString withFormat:@"yyyyMMdd HH':'mm':'ss"];
        }
    }
    return self;
}



- (void)dealloc {
    [_phone release];
    [_date release];
    [_address release];
    
    [super dealloc];
}



+ (NSString *)statusStringForState:(OrderState)state {
    switch (state) {
        case OrderStateAdded: return @"создан";
        case OrderStateInitiated: return @"инициирована оплата";
        case OrderStateConfirmed: return @"оплачен, не доставлен";
        case OrderStateFailed: return @"ошибка оплаты";
        case OrderStateCancelled: return @"оплата отменена";
        case OrderStateDelivered: return @"оплачен, доставлен";
    }
}



- (NSString *)statusString {
    return [OrderModel statusStringForState:self.state];
}

@end
