//
//  ServiceRequestBuilder.m
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "ServiceRequestBuilder.h"

#import "NSString+MD5.h"



@interface ServiceRequestBuilder ()

@end




@implementation ServiceRequestBuilder

#pragma mark -
#pragma mark Singleton implementation
static ServiceRequestBuilder *_sharedInstance = nil;



+ (instancetype)sharedInstance {
    if (!_sharedInstance)
        _sharedInstance = [[ServiceRequestBuilder alloc] init];
    
    return _sharedInstance;
}


- (id)init {
    self = [super init];
    if (self) {
    }
    return self;
}


- (void)dealloc {
    [super dealloc];
}


- (oneway void)release {
}


- (id)retain {
    return self;
}


- (id)autorelease {
    return self;
}


- (NSUInteger)retainCount {
    return INT_MAX;
}



#pragma mark -
#pragma mark Building requests
- (ServiceRequest *)requestGoods {
    ServiceRequest *request = [[[ServiceRequest alloc] init] autorelease];
    request.responseClass = [ServiceResponseModelItems class];
    request.responseParameter = NSStringFromClass([GoodsModel class]);
    
    request.endpointResource = @"goods.php";
    
    return request;
}



- (ServiceRequest *)requestCreateOrder:(NSString *)cart deviceId:(NSString *)deviceId {
    ServiceRequest *request = [[[ServiceRequest alloc] init] autorelease];
    request.responseClass = [ServiceResponseJSON class];
    
    request.endpointResource = @"order.php";
    request.getParameters = @{
                              @"action" : @"create",
                              @"cart" : cart,
                              @"device_id" : deviceId
                              };
    
    return request;
}



- (ServiceRequest *)requestInitiateOrder:(NSUInteger)orderId phone:(NSString *)phone address:(NSString *)address details:(NSString *)details {
    ServiceRequest *request = [[[ServiceRequest alloc] init] autorelease];
    request.responseClass = [ServiceResponseJSON class];
    
    request.endpointResource = @"order.php";
    
    NSMutableDictionary *getDict = [NSMutableDictionary dictionary];
    getDict[@"action"] = @"initiate";
    getDict[@"order_id"] = @(orderId);
    if (phone) getDict[@"phone"] = phone;
    if (address) getDict[@"address"] = address;
    if (details) getDict[@"details"] = details;
    
    request.getParameters = getDict;
    
    return request;
}



- (ServiceRequest *)requestConfirmOrder:(NSUInteger)orderId code:(NSString *)code {
    ServiceRequest *request = [[[ServiceRequest alloc] init] autorelease];
    request.responseClass = [ServiceResponseJSON class];
    
    request.endpointResource = @"order.php";
    request.getParameters = @{
                              @"action" : @"confirm",
                              @"order_id" : @(orderId),
                              @"code" : code
                              };
    
    return request;
}



- (ServiceRequest *)requestDiscardOrder:(NSUInteger)orderId {
    return [self requestConfirmOrder:orderId code:@"-1"];
}



- (ServiceRequest *)requestOrdersWithDeviceId:(NSString *)deviceId {
    ServiceRequest *request = [[[ServiceRequest alloc] init] autorelease];
    request.responseClass = [ServiceResponseModelItems class];
    request.responseParameter = NSStringFromClass([OrderModel class]);
    
    request.endpointResource = @"order.php";
    request.getParameters = @{
                              @"action" : @"list",
                              @"device_id" : deviceId
                              };
    
    return request;
}



- (ServiceRequest *)requestGlobalSettings {
    ServiceRequest *request = [[[ServiceRequest alloc] init] autorelease];
    request.responseClass = [ServiceResponseJSON class];
    
    request.endpointResource = @"settings.php";
    request.getParameters = @{
                              @"action" : @"global"
                              };
    
    return request;
}

@end
