//
//  ServerSettingsManager.m
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "ServerSettingsManager.h"

#import "ServiceRequestBuilder.h"


NSString * const kSettingsLoadedKey = @"serverSettingsLoaded";
NSString * const kCurrencyNameKey = @"serverSettingsCurrencyName";



@interface ServerSettingsManager ()

@property (nonatomic, readwrite, assign) BOOL settingsLoaded;
@property (nonatomic, readwrite, retain) NSString *currencyName;

@end




@implementation ServerSettingsManager {
    BOOL _setingsLoaded;
}


#pragma mark -
#pragma mark Singleton implementation
static ServerSettingsManager *_sharedInstance = nil;



+ (ServerSettingsManager *)sharedInstance {
    if (!_sharedInstance)
        _sharedInstance = [[ServerSettingsManager alloc] init];
    
    return _sharedInstance;
}


- (id)init {
    self = [super init];
    if (self) {
        // Try to load locally stored settings
        NSUserDefaults *ud = [NSUserDefaults standardUserDefaults];
        self.settingsLoaded = [ud boolForKey:kSettingsLoadedKey];
        if (self.settingsLoaded) {
            self.currencyName = [ud stringForKey:kCurrencyNameKey];
        }
    }
    return self;
}


- (void)dealloc {
    [_currencyName release];
    
    [super dealloc];
}


- (oneway void)release {
}


- (id)retain {
    return self;
}


- (id)autorelease {
    return self;
}


- (NSUInteger)retainCount {
    return INT_MAX;
}



#pragma mark -
#pragma mark Loading settings
- (void)loadWithComplitionHandler:(ServerSettingsCallback)complitionHandler {
    ServiceRequest *settingsRequest = [[ServiceRequestBuilder sharedInstance] requestGlobalSettings];
    
    settingsRequest.successBlock = ^ (ServiceRequest *request) {
        ServiceResponseJSON *jsonResponse = (id)request.response;
        
        // Get data from response
        self.currencyName = jsonResponse.response[@"currency_name"];
        self.settingsLoaded = YES;
        
        // Store settings locally
        NSUserDefaults *ud = [NSUserDefaults standardUserDefaults];
        [ud setObject:self.currencyName forKey:kCurrencyNameKey];
        [ud setBool:YES forKey:kSettingsLoadedKey];
        [ud synchronize];
        
        if (complitionHandler)
            complitionHandler(nil);
    };
    
    settingsRequest.failBlock = ^ (ServiceRequest *request) {
        if (complitionHandler)
            complitionHandler(request.error);
    };
    
    [[ServiceManager sharedInstance] processRequest:settingsRequest];
}



#pragma mark -
#pragma mark Helpers
- (NSString *)stringForPrice:(float)price {
    if (self.currencyName) return [NSString stringWithFormat:@"%0.2f %@", price, self.currencyName];
    else return [NSString stringWithFormat:@"%0.2f", price];
}

@end
