//
//  ServiceResponseJSON.m
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "ServiceResponseJSON.h"

#import "NSError+Constructing.h"
#import "ServiceGlobals.h"



@implementation ServiceResponseJSON

- (instancetype)initWithData:(NSData *)data statusCode:(NSInteger)statusCode parameter:(id)parameter {
    self = [super initWithData:data statusCode:statusCode parameter:parameter];
    if (self) {
        NSError *err = nil;
        NSDictionary *rootDict = [NSJSONSerialization JSONObjectWithData:data options:0 error:&err];
        if (err) {
            self.error = [NSError errorWithDomain:kServiceErrorDomain
                                             code:kServiceJSONDeserializationErrorCode
                             localizedDescription:@"Can not deserialize response body from JSON."
                                   customUserInfo:@{ kServiceDetailedErrorUserInfoKey : err }];
            return self;
        }
        
        self.code = [rootDict[@"code"] integerValue];
        self.message = rootDict[@"message"];
        self.response = rootDict[@"response"];
        
        if (![self isOk]) {
            self.error = [NSError errorWithDomain:kServiceErrorDomain
                                             code:self.code
                             localizedDescription:self.message];
            return self;
        }
    }
    return self;
}



- (void)dealloc {
    [_message release];
    [_response release];
    
    [super dealloc];
}



- (BOOL)isOk {
    return (self.code == kServiceResponseNoErrorCode);
}

@end
