//
//  NSString+URLParameters.m
//  DSTGTest
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "NSString+URLParameters.h"

#import "NSString+URLEncoding.h"


@implementation NSString (URLParameters)

+ (NSString *)urlParametersStringWithDictionary:(NSDictionary *)dictionary {
    NSMutableArray *pairs = [[NSMutableArray alloc] init];
    
    for (NSString *key in dictionary) {
        id value = [dictionary objectForKey:key];
        NSString *pair = [self keyValueStringForValue:value withKey:key];
        [pairs addObject:pair];
    }
    
    NSString *strBody = [pairs componentsJoinedByString:@"&"];
    [pairs release];
    
    return strBody;
}



+ (NSString *)keyValueStringForValue:(id)value withKey:(NSString *)key {
    // String
    if ([value isKindOfClass:[NSString class]]) {
        return [NSString stringWithFormat:@"%@=%@", key, [value encodedURLParameterString]];    
    }
    // Number
    else if ([value isKindOfClass:[NSNumber class]]) {
        NSString *strValue = [value stringValue];
        return [NSString stringWithFormat:@"%@=%@", key, [strValue encodedURLParameterString]];
    }
    // Array
    else if ([value isKindOfClass:[NSArray class]]) {
        NSMutableArray *pairs = [NSMutableArray arrayWithCapacity:[value count]];
        for (id item in value) {
            NSString *pair = [self keyValueStringForValue:item
                                                  withKey:[key stringByAppendingString:@"[]"]];
            [pairs addObject:pair];
        }
        return [pairs componentsJoinedByString:@"&"];
    }
    // Dictionary / Explainable parameter
    else if ([value isKindOfClass:[NSDictionary class]]) {
        NSMutableArray *pairs = [NSMutableArray arrayWithCapacity:[value count]];
        
        // Explainable parameter
        if ([key hasPrefix:kExplainableParameterPrefix]) {
            for (NSString *subkey in value) {
                id subvalue = value[subkey];
                NSString *pair = [self keyValueStringForValue:subvalue withKey:subkey];
                [pairs addObject:pair];
            }
        }
        // Dictionary
        else {
            NSMutableArray *pairs = [NSMutableArray arrayWithCapacity:[value count]];
            for (id subkey in value) {
                id subvalue = value[subkey];
                NSString *pair = [self keyValueStringForValue:subvalue
                                                      withKey:[NSString stringWithFormat:@"%@[%@]", key, subkey]];
                [pairs addObject:pair];
            }
        }
    
        return [pairs componentsJoinedByString:@"&"];
    }
    
    return [NSString stringWithFormat:@"%@=%@", key, [[value description] encodedURLParameterString]];
}

@end
