//
//  NSURLConnectionContainer.h
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

// http://stackoverflow.com/questions/7862316/ios5-nsurlconnection-methods-deprecated

#import <UIKit/UIKit.h>


@class URLConnectionContainer;


@protocol URLConnectionContainerDelegate <NSObject>

@optional

- (BOOL)connectionContainer:(URLConnectionContainer *)connectionContainer canAuthenticateAgainstProtectionSpace:(NSURLProtectionSpace *)protectionSpace ;
- (void)connectionContainer:(URLConnectionContainer *)connectionContainer didCancelAuthenticationChallenge:(NSURLAuthenticationChallenge *)challenge;
- (void)connectionContainer:(URLConnectionContainer *)connectionContainer didFailWithError:(NSError *)error;
- (void)connectionContainer:(URLConnectionContainer *)connectionContainer didReceiveAuthenticationChallenge:(NSURLAuthenticationChallenge *)challenge;
- (void)connectionContainer:(URLConnectionContainer *)connectionContainer didReceiveResponse:(NSURLResponse *)response;
- (NSInputStream *)connectionContainer:(URLConnectionContainer *)connectionContainer needNewBodyStream:(NSURLRequest *)request;
- (NSCachedURLResponse *)connectionContainer:(URLConnectionContainer *)connectionContainer willCacheResponse:(NSCachedURLResponse *)cachedResponse;
- (NSURLRequest *)connectionContainer:(URLConnectionContainer *)inConnectionContainer willSendRequest:(NSURLRequest *)inRequest redirectResponse:(NSURLResponse *)inRedirectResponse;
- (void)connectionContainerDidFinishLoading:(URLConnectionContainer *)connectionContainer;
- (BOOL)connectionContainerShouldUseCredentialStorage:(URLConnectionContainer*)connectionContainer;

@end



@protocol URLConnectionContainerUploadingProgressDelegate <NSObject>

@optional

- (void)connectionContainer:(URLConnectionContainer *)connectionContainer didSendBodyData:(NSInteger)bytesWritten totalBytesWritten:(NSInteger)totalBytesWritten totalBytesExpectedToWrite:(NSInteger)totalBytesExpectedToWrite;

@end




@protocol URLConnectionContainerDownloadingProgressDelegate <NSObject>

@optional

- (void)connectionContainer:(URLConnectionContainer *)connectionContainer didReceiveData:(NSData *)data;

@end




@interface URLConnectionContainer : NSObject

- (id)initWithURLRequest:(NSURLRequest *)request;
+ (id)connectionContainerWithURLRequest:(NSURLRequest *)request;

- (void)startAsync:(BOOL)async;
- (void)cancel;

@property (nonatomic, readonly, retain) NSURLConnection *connection;
@property (nonatomic, readonly, retain) NSURLRequest *request;
@property (nonatomic, readwrite, retain) NSString *username;
@property (nonatomic, readwrite, retain) NSString *password;

@property (nonatomic, readonly, retain) NSMutableData *responseData;
@property (nonatomic, readonly, retain) NSString *responseString;
@property (nonatomic, readonly, retain) NSArray *responseCookies;
@property (nonatomic, readonly, retain) NSURLResponse *urlResponse;
@property (nonatomic, readonly, retain) NSError *error;

@property (nonatomic, readwrite, assign) NSStringEncoding responseStringEncoding;

@property (nonatomic, readonly, assign) BOOL inProgress;

@property (nonatomic, readwrite, assign) id<URLConnectionContainerDelegate> delegate;
@property (nonatomic, readwrite, assign) id<URLConnectionContainerUploadingProgressDelegate> uploadingProgressDelegate;
@property (nonatomic, readwrite, assign) id<URLConnectionContainerDownloadingProgressDelegate> downlodingProgressDelegate;

@property (nonatomic, readonly, assign) long long bytesWritten;
@property (nonatomic, readonly, assign) long long bytesExpectedToWrite;
@property (nonatomic, readonly, assign) long long bytesRead;
@property (nonatomic, readonly, assign) long long bytesExpectedToRead;

@property (nonatomic, readonly, assign) BOOL authorizationFailed;

@end
