//
//  CartManager.m
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "CartManager.h"


NSString * const kCartChangedNotification = @"kCartChangedNotification";




@interface CartManager ()

@property (nonatomic, readwrite, retain) NSMutableDictionary *items;

@end




@implementation CartManager

#pragma mark -
#pragma mark Singleton implementation
static CartManager *_sharedInstance = nil;



+ (instancetype)sharedInstance {
    if (!_sharedInstance)
        _sharedInstance = [[CartManager alloc] init];
    
    return _sharedInstance;
}


- (id)init {
    self = [super init];
    if (self) {
        self.items = [NSMutableDictionary dictionary];
    }
    return self;
}


- (void)dealloc {
    [_items release];
    
    [super dealloc];
}


- (oneway void)release {
}


- (id)retain {
    return self;
}


- (id)autorelease {
    return self;
}


- (NSUInteger)retainCount {
    return INT_MAX;
}




#pragma mark -
#pragma mark Managing goods
- (void)addGoods:(GoodsModel *)goods count:(NSUInteger)count {
    CartItem *item = self.items[@(goods.identifier)];
    if (item) {
        item.count += count;
    }
    else {
        item = [CartItem itemWithGoods:goods count:count];
        self.items[@(goods.identifier)] = item;
    }
    
    [[NSNotificationCenter defaultCenter] postNotificationName:kCartChangedNotification object:nil];
}



- (void)removeGoods:(GoodsModel *)goods count:(NSUInteger)count {
    CartItem *item = self.items[@(goods.identifier)];
    if (item) {
        if (item.count > count) {
            item.count -= count;
        }
        else {
            [self.items removeObjectForKey:@(goods.identifier)];
        }
        
        [[NSNotificationCenter defaultCenter] postNotificationName:kCartChangedNotification object:nil];
    }
}



- (void)removeAllGoods:(GoodsModel *)goods {
    CartItem *item = self.items[@(goods.identifier)];
    if (!item) return;
    
    [self.items removeObjectForKey:@(goods.identifier)];
    
    [[NSNotificationCenter defaultCenter] postNotificationName:kCartChangedNotification object:nil];
}



- (void)clean {
    if (![self.items count]) return;
    
    [self.items removeAllObjects];
    
    [[NSNotificationCenter defaultCenter] postNotificationName:kCartChangedNotification object:nil];
}



- (NSString *)packedCartString {
    NSMutableString *packedString = [NSMutableString string];
    
    BOOL firstItem = YES;
    for (NSNumber *goodsId in self.items) {
        CartItem *cartItem = self.items[goodsId];
        
        NSString *goodsString = [NSString stringWithFormat:@"%@%@-%d", firstItem ? @"" : @",", goodsId, (int)cartItem.count];
        [packedString appendString:goodsString];
        
        firstItem = NO;
    }
    
    return packedString;
}



- (NSArray *)getAllItems {
    return [self.items allValues];
}

@end
