//
//  ConfirmPaymentVC.m
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "ConfirmOrderVC.h"

#import "ServiceRequestBuilder.h"
#import "CartManager.h"
#import "ServerSettingsManager.h"

#import "TextFieldCell.h"

#import "ActivityVC.h"
#import "OrdersVC.h"


NSInteger const kConfirmOrderSercionIndex = 0;
NSInteger const kConfirmFieldsSectionIndex = 1;

NSInteger const kCodeCellIndex = 2;

#define CODE_CELL (_sections[kConfirmFieldsSectionIndex][kCodeCellIndex])



@interface ConfirmOrderVC () <UIAlertViewDelegate>

- (IBAction)actionConfirm:(id)sender;

@end



@implementation ConfirmOrderVC {
    NSMutableArray *_sections;
    BOOL _focusSet;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    // Create cells
    _sections = [[NSMutableArray alloc] init];
    
    NSMutableArray *detailsSection = [NSMutableArray array];
    [_sections addObject:detailsSection];
    
    UITableViewCell *cell = [self.tableView dequeueReusableCellWithIdentifier:@"TitleValueCell"];
    cell.textLabel.text = @"Номер заказа:";
    cell.detailTextLabel.text = [NSString stringWithFormat:@"#%d", (int)self.orderId];
    [detailsSection addObject:cell];
    
    cell = [self.tableView dequeueReusableCellWithIdentifier:@"TitleValueCell"];
    cell.textLabel.text = @"Сумма заказа:";
    cell.detailTextLabel.text = [[ServerSettingsManager sharedInstance] stringForPrice:self.amount];
    [detailsSection addObject:cell];
    
    
    NSMutableArray *userSection = [NSMutableArray array];
    [_sections addObject:userSection];
    
    TextFieldCell *tfCell = [self.tableView dequeueReusableCellWithIdentifier:@"TextFieldCell"];
    tfCell.lblTitle.text = @"Номер мобильного телефона:";
    tfCell.lblSubtitle.text = @"код страны и цифры, например: 79161234568";
    tfCell.txtText.text = self.phone;
    tfCell.txtText.enabled = NO;
    [userSection addObject:tfCell];
    
    tfCell = [self.tableView dequeueReusableCellWithIdentifier:@"TextFieldCell"];
    tfCell.lblTitle.text = @"Адрес доставки:";
    tfCell.lblSubtitle.text = @"улица, номер дома, номер квартиры";
    tfCell.txtText.text = self.address;
    tfCell.txtText.enabled = NO;
    [userSection addObject:tfCell];
    
    tfCell = [self.tableView dequeueReusableCellWithIdentifier:@"TextFieldCell"];
    tfCell.lblTitle.text = @"Код подтверждения:";
    tfCell.lblSubtitle.text = @"был выслан вам в SMS-сообщении";
    tfCell.txtText.keyboardType = UIKeyboardTypeNumberPad;
    [userSection addObject:tfCell];
}



- (void)dealloc {
    [_sections release];
    [_phone release];
    [_address release];
    
    [super dealloc];
}



#pragma mark - Table view
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return [_sections count];
}



- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    NSArray *sectionCells = _sections[section];
    return [sectionCells count];
}



- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    if (section == kConfirmOrderSercionIndex) return @"Детали заказа";
    else if (section == kConfirmFieldsSectionIndex) return @"Оплатить при помощи WebMoney";
    
    return nil;
}



- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = _sections[indexPath.section][indexPath.row];
    
    if (indexPath.section == kConfirmFieldsSectionIndex && indexPath.row == kCodeCellIndex) {
        TextFieldCell *tfCell = (TextFieldCell *)cell;
        
        if (!_focusSet && [tfCell.txtText.text length] == 0) {
            [tfCell.txtText becomeFirstResponder];
            _focusSet = YES;
        }
    }
    
    return cell;
}



- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return (indexPath.section == kConfirmFieldsSectionIndex) ? 98.0f : 44.0f;
}



#pragma mark -
#pragma mark Actions
- (IBAction)actionConfirm:(id)sender {
    TextFieldCell *codeCell = CODE_CELL;
    NSString *code = codeCell.txtText.text;
    
    if (![code length]) {
        if (codeCell.txtText.isFirstResponder) {
            [[[[UIAlertView alloc] initWithTitle:@"Неверные данные" message:@"Не указан код подтверждения" delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil] autorelease] show];
        }
        else {
            [codeCell.txtText becomeFirstResponder];
        }
        return;
    }
    
    [codeCell.txtText resignFirstResponder];
    
    [self confirmOrderWithCode:code];
}



//- (IBAction)actionDiscard:(id)sender {
//    ServiceRequest *discardRequest = [[ServiceRequestBuilder sharedInstance] requestDiscardOrder:self.orderId];
//    
//    discardRequest.successBlock = ^ (ServiceRequest *request) {
//        [self showErrorMessage:@"Платеж успешно отменен!" title:@"Оплата"];
//        
//        [self.navigationController popToRootViewControllerAnimated:YES];
//    };
//    
//    discardRequest.failBlock = ^ (ServiceRequest *request) {
//        [self showErrorMessage:request.error.localizedDescription title:@"Оплата"];
//    };
//    
//    [[ServiceManager sharedInstance] processRequest:discardRequest];
//}



- (void)confirmOrderWithCode:(NSString *)code {
    [[ActivityVC sharedInstance] showInViewController:self.tabBarController];
    
    ServiceRequest *confirmRequest = [[ServiceRequestBuilder sharedInstance] requestConfirmOrder:self.orderId code:code];
    
    confirmRequest.successBlock = ^ (ServiceRequest *request) {
        [[ActivityVC sharedInstance] hide];
        
        UIAlertView *av = [[[UIAlertView alloc] initWithTitle:@"Оплата" message:@"Платеж успешно подтвержден!" delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil] autorelease];
        av.delegate = self;
        av.tag = kServiceResponseNoErrorCode;
        [av show];
        
        [[CartManager sharedInstance] clean];
    };
    
    confirmRequest.failBlock = ^ (ServiceRequest *request) {
        [[ActivityVC sharedInstance] hide];
        
        ServiceResponseJSON *jsonResponse = (id)request.response;
        
        UIAlertView *av = [[[UIAlertView alloc] initWithTitle:@"Оплата" message:request.error.localizedDescription delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil] autorelease];
        av.delegate = self;
        av.tag = jsonResponse.code;
        [av show];
    };
    
    [[ServiceManager sharedInstance] processRequest:confirmRequest];
}



#pragma mark -
#pragma mark Alert view delegate
- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex {
    if (alertView.tag == kServiceResponseNoErrorCode || alertView.tag == kServiceResponseTooManyConfirmFails) {
        self.tabBarController.selectedIndex = 2;
        [[NSNotificationCenter defaultCenter] postNotificationName:kOrdersUpdatedNotification object:nil];
        
        [self.navigationController popToRootViewControllerAnimated:NO];
    }
    else {
        TextFieldCell *codeCell = CODE_CELL;
        [codeCell.txtText becomeFirstResponder];
        [codeCell.txtText selectAll:nil];
    }
}

@end
