//
//  LoginVC.h
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "InitiateOrderVC.h"

#import "ServiceRequestBuilder.h"
#import "ServerSettingsManager.h"

#import "ConfirmOrderVC.h"
#import "ActivityVC.h"

#import "TextFieldCell.h"



NSString * const kPhoneKey = @"phone";
NSString * const kAddressKey = @"address";


NSInteger const kInitiateOrderSercionIndex = 0;
NSInteger const kInitiateFieldsSectionIndex = 1;

NSInteger const kPhoneCellIndex = 0;
NSInteger const kAddressCellIndex = 1;

#define PHONE_CELL (_sections[kInitiateFieldsSectionIndex][kPhoneCellIndex])
#define ADDRESS_CELL (_sections[kInitiateFieldsSectionIndex][kAddressCellIndex])



@interface InitiateOrderVC ()

- (IBAction)actionPay:(id)sender;

@property (nonatomic, readwrite, retain) NSString *currentPhone;
@property (nonatomic, readwrite, retain) NSString *currentAddress;

@end



@implementation InitiateOrderVC {
    NSMutableArray *_sections;
    BOOL _focusSet;
}


- (void)viewDidLoad {
    [super viewDidLoad];
    
    // Create cells
    NSUserDefaults *ud = [NSUserDefaults standardUserDefaults];
    NSString *udPhone = [ud objectForKey:kPhoneKey];
    NSString *udAddress = [ud objectForKey:kAddressKey];
    
    _sections = [[NSMutableArray alloc] init];
    
    NSMutableArray *detailsSection = [NSMutableArray array];
    [_sections addObject:detailsSection];
    
    UITableViewCell *cell = [self.tableView dequeueReusableCellWithIdentifier:@"TitleValueCell"];
    cell.textLabel.text = @"Номер заказа:";
    cell.detailTextLabel.text = [NSString stringWithFormat:@"#%d", (int)self.orderId];
    [detailsSection addObject:cell];
    
    cell = [self.tableView dequeueReusableCellWithIdentifier:@"TitleValueCell"];
    cell.textLabel.text = @"Сумма заказа:";
    cell.detailTextLabel.text = [[ServerSettingsManager sharedInstance] stringForPrice:self.amount];
    [detailsSection addObject:cell];
    
    
    NSMutableArray *userSection = [NSMutableArray array];
    [_sections addObject:userSection];
    
    TextFieldCell *tfCell = [self.tableView dequeueReusableCellWithIdentifier:@"TextFieldCell"];
    tfCell.lblTitle.text = @"Номер мобильного телефона:";
    tfCell.lblSubtitle.text = @"код страны и цифры, например: 79161234568";
    tfCell.txtText.keyboardType = UIKeyboardTypeNumberPad;
    if ([ud objectForKey:kPhoneKey])
        tfCell.txtText.text = udPhone;
    [userSection addObject:tfCell];
    
    tfCell = [self.tableView dequeueReusableCellWithIdentifier:@"TextFieldCell"];
    tfCell.lblTitle.text = @"Адрес доставки:";
    tfCell.lblSubtitle.text = @"улица, номер дома, номер квартиры";
    if ([ud objectForKey:kAddressKey])
        tfCell.txtText.text = udAddress;
    [userSection addObject:tfCell];
}



- (void)dealloc {
    [_sections release];
    [_currentPhone release];
    
    [super dealloc];
}



#pragma mark - Table view
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return [_sections count];
}



- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    NSArray *sectionCells = _sections[section];
    return [sectionCells count];
}



- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    if (section == kInitiateOrderSercionIndex) return @"Детали заказа";
    else if (section == kInitiateFieldsSectionIndex) return @"Оплатить при помощи WebMoney";
    
    return nil;
}



- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = _sections[indexPath.section][indexPath.row];
    
    if (indexPath.section == kInitiateFieldsSectionIndex) {
        TextFieldCell *tfCell = (TextFieldCell *)cell;
        
        if (!_focusSet && [tfCell.txtText.text length] == 0) {
            [tfCell.txtText becomeFirstResponder];
            _focusSet = YES;
        }
    }
    
    return cell;
}



- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return (indexPath.section == kInitiateFieldsSectionIndex) ? 98.0f : 44.0f;
}



#pragma mark -
#pragma marn Actions
- (IBAction)actionPay:(id)sender {
    // Get fields data
    TextFieldCell *phoneCell = PHONE_CELL;
    self.currentPhone = phoneCell.txtText.text;
    
    TextFieldCell *addressCell = ADDRESS_CELL;
    self.currentAddress = addressCell.txtText.text;
    
    // Check data
    if (![self.currentPhone length]) {
        if (phoneCell.txtText.isFirstResponder) {
            [[[[UIAlertView alloc] initWithTitle:@"Неверные данные" message:@"Не указан номер телефона" delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil] autorelease] show];
        }
        else {
            [phoneCell.txtText becomeFirstResponder];
        }
        return;
    }
    
    if (![self.currentAddress length]) {
        if (addressCell.txtText.isFirstResponder) {
            [[[[UIAlertView alloc] initWithTitle:@"Неверные данные" message:@"Не указан адрес доставки" delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil] autorelease] show];
        }
        else {
            [addressCell.txtText becomeFirstResponder];
        }
        return;
    }
    
    [phoneCell.txtText resignFirstResponder];
    [addressCell.txtText resignFirstResponder];
    
    // Store data to user defaults
    NSUserDefaults *ud = [NSUserDefaults standardUserDefaults];
    [ud setObject:self.currentPhone forKey:kPhoneKey];
    
    if (self.currentAddress) [ud setObject:self.currentAddress forKey:kAddressKey];
    else [ud removeObjectForKey:kAddressKey];
    
    [ud synchronize];
    
    // Initiate payment
    [self initiateOrderWithPhone:self.currentPhone address:self.currentAddress details:nil];
}



- (void)initiateOrderWithPhone:(NSString *)phone address:(NSString *)address details:(NSString *)details {
    [[ActivityVC sharedInstance] showInViewController:self.tabBarController];
    
    ServiceRequest *loginRequest = [[ServiceRequestBuilder sharedInstance] requestInitiateOrder:self.orderId phone:phone address:address details:details];
    
    loginRequest.successBlock = ^ (ServiceRequest *request) {
        [[ActivityVC sharedInstance] hide];
        
        [self performSegueWithIdentifier:@"sgShowConfirmOrder" sender:self];
    };
    
    loginRequest.failBlock = ^ (ServiceRequest *request) {
        [[ActivityVC sharedInstance] hide];
        
        [[[[UIAlertView alloc] initWithTitle:@"Ошибка оплаты" message:request.error.localizedDescription delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil] autorelease] show];
    };
    
    [[ServiceManager sharedInstance] processRequest:loginRequest];
}



#pragma mark -
#pragma mark Navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    if ([segue.identifier isEqualToString:@"sgShowConfirmOrder"]) {
        ConfirmOrderVC *confirmVC = segue.destinationViewController;
        confirmVC.orderId = self.orderId;
        confirmVC.amount = self.amount;
        confirmVC.phone = self.currentPhone;
        confirmVC.address = self.currentAddress;
    }
}

@end
