//
//  MenuVC.m
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "MenuVC.h"

#import "ServiceRequestBuilder.h"
#import "CartManager.h"

#import "MenuCell.h"

#import "ActivityVC.h"



@interface MenuVC ()

@property (nonatomic, readwrite, retain) NSArray *goods;

@end



@implementation MenuVC

- (void)dealloc {
    [_goods release];
    
    [super dealloc];
}



- (void)viewDidLoad {
    [super viewDidLoad];
    
    [self refreshGoodsList];
}



- (void)refreshGoodsList {
    [[ActivityVC sharedInstance] showInViewController:self.tabBarController];
    
    ServiceRequest *goodsRequest = [[ServiceRequestBuilder sharedInstance] requestGoods];
    
    goodsRequest.successBlock = ^ (ServiceRequest *request) {
        [[ActivityVC sharedInstance] hide];
        
        ServiceResponseModelItems *response = (id)request.response;
        
        self.goods = response.items;
        [self.tableView reloadData];
    };
    
    goodsRequest.failBlock = ^ (ServiceRequest *request) {
        [[ActivityVC sharedInstance] hide];
        
        [[[[UIAlertView alloc] initWithTitle:@"Меню - Ошибка" message:request.error.localizedDescription delegate:Nil cancelButtonTitle:@"OK" otherButtonTitles:nil] autorelease] show];
    };
    
    [[ServiceManager sharedInstance] processRequest:goodsRequest];
}



#pragma mark - Table view data source
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [self.goods count];
}



- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    MenuCell *cell = [tableView dequeueReusableCellWithIdentifier:@"GoodsCell" forIndexPath:indexPath];
    
    GoodsModel *goods = self.goods[indexPath.row];
    cell.goods = goods;
    
    cell.buyButton.tag = indexPath.row;
    
    if (!cell.initialized) {
        [cell.buyButton addTarget:self action:@selector(actionBuy:) forControlEvents:UIControlEventTouchUpInside];
    }
    
    
    for (id obj in cell.subviews) {
        if ([obj isKindOfClass:[UIScrollView class]]) {
            UIScrollView *scroll = (UIScrollView *) obj;
            scroll.delaysContentTouches = NO;
            break;
        }
    }
    
    
    cell.initialized = YES;
    return cell;
}



- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 84.0f;
}



#pragma mark - Actions
- (void)actionBuy:(UIButton *)sender {
    GoodsModel *goods = self.goods[sender.tag];
    [[CartManager sharedInstance] addGoods:goods count:1];
}



- (IBAction)actionRefresh:(id)sender {
    [self refreshGoodsList];
}

@end
