//
//  OrdersVC.m
//  AppPiza
//
//  Copyright (c) 2014 CJSC "Computing Forces"
//

#import "OrdersVC.h"

#import "OrderCell.h"

#import "ServiceRequestBuilder.h"
#import "DeviceIDManager.h"

#import "ActivityVC.h"



NSString * const kOrdersUpdatedNotification = @"ordersUpdatedNotification";




@interface OrdersVC ()

@property (nonatomic, readwrite, retain) NSArray *orders;

@end



@implementation OrdersVC

- (id)initWithCoder:(NSCoder *)aDecoder {
    self = [super initWithCoder:aDecoder];
    if (self) {
        [self refreshOrdersList];
        
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(ordersUpdatedNotification:) name:kOrdersUpdatedNotification object:nil];
    }
    return self;
}



- (void)dealloc {
    [[NSNotificationCenter defaultCenter] removeObserver:self name:kOrdersUpdatedNotification object:nil];
    
    [super dealloc];
}



- (void)viewDidLoad {
    [super viewDidLoad];
}



- (void)refreshOrdersList {
    [[ActivityVC sharedInstance] showInViewController:self.tabBarController];
    
    NSString *deviceId = [DeviceIDManager sharedInstance].currentDeviceUUID;
    ServiceRequest *ordersRequest = [[ServiceRequestBuilder sharedInstance] requestOrdersWithDeviceId:deviceId];
    
    ordersRequest.successBlock = ^ (ServiceRequest *request) {
        [[ActivityVC sharedInstance] hide];
        
        ServiceResponseModelItems *response = (id)request.response;
        
        NSSortDescriptor *sortDescriptor = [NSSortDescriptor sortDescriptorWithKey:@"date" ascending:NO];
        self.orders = [response.items sortedArrayUsingDescriptors:@[ sortDescriptor ]];
        
        // Update table view
        if ([self isViewLoaded]) {
            [self.tableView reloadData];
        }
        
        // Update badge
        NSUInteger confirmedCount = 0;
        for (OrderModel *order in self.orders) {
            if (order.state == OrderStateConfirmed)
                confirmedCount++;
        }
        self.navigationController.tabBarItem.badgeValue = confirmedCount ? [@(confirmedCount) stringValue] : nil;
    };
    
    ordersRequest.failBlock = ^ (ServiceRequest *request) {
        [[ActivityVC sharedInstance] hide];
        
        [[[[UIAlertView alloc] initWithTitle:@"Заказы - Ошибка" message:request.error.localizedDescription delegate:Nil cancelButtonTitle:@"OK" otherButtonTitles:nil] autorelease] show];
    };
    
    [[ServiceManager sharedInstance] processRequest:ordersRequest];
}



#pragma mark - Table view data source
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [self.orders count];
}



- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    OrderCell *cell = [tableView dequeueReusableCellWithIdentifier:@"OrderCell" forIndexPath:indexPath];
    
    OrderModel *order = self.orders[indexPath.row];
    cell.order = order;
    
    return cell;
}



#pragma mark -
#pragma mark Actions
- (IBAction)actionRefresh:(id)sender {
    [self refreshOrdersList];
}



#pragma mark -
#pragma mark Notifications
- (void)ordersUpdatedNotification:(NSNotification *)notification {
    [self refreshOrdersList];
}

@end
